@@ -21,7 +21,8 @@ _dothis_completions()
   elif perl -e '$w=$ENV{cur_word}; exit(0) unless $w; $w=~/^-+/ or exit 2'; then
 
 
-    COMPREPLY=( $( compgen -W "--help --completion --last --profile --list --edit --cat -q --quiet --verbose --lines --env" -- ${cur_word} ))
+    COMPREPLY=( $( compgen -W "--help --completion --last --profile --list --edit --cat -q --quiet --verbose --lines --env --env-list 
+--env-edit --env-set" -- ${cur_word} ))
 
   else
 
